==> camunda-cmmn-model-7.2.0-test-sources.jar: org/camunda/bpm/model/cmmn/instance/CaseFileItemTest.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.model.cmmn.instance;

import java.util.Arrays;
import java.util.Collection;

import org.camunda.bpm.model.cmmn.MultiplicityEnum;

/**
 * @author Roman Smirnov
 *
 */
public class CaseFileItemTest extends CmmnModelElementInstanceTest {

  public TypeAssumption getTypeAssumption() {
    return new TypeAssumption(CmmnElement.class, false);
  }

  public Collection<ChildElementAssumption> getChildElementAssumptions() {
    return Arrays.asList(
          new ChildElementAssumption(Children.class, 0, 1)
        );
  }

  public Collection<AttributeAssumption> getAttributesAssumptions() {
    return Arrays.asList(
          new AttributeAssumption("name"),
          new AttributeAssumption("multiplicity", false, false, MultiplicityEnum.Unspecified),
          new AttributeAssumption("definitionRef"),
          new AttributeAssumption("sourceRef"),
          new AttributeAssumption("targetRefs")
        );
  }

}

==> camunda-cmmn-model-7.5.0-test-sources.jar: org/camunda/bpm/model/cmmn/instance/CaseFileItemTest.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.model.cmmn.instance;

import java.util.Arrays;
import java.util.Collection;

import org.camunda.bpm.model.cmmn.MultiplicityEnum;
import org.camunda.bpm.model.cmmn.impl.CmmnModelConstants;

/**
 * @author Roman Smirnov
 *
 */
public class CaseFileItemTest extends CmmnModelElementInstanceTest {

  public TypeAssumption getTypeAssumption() {
    return new TypeAssumption(CmmnElement.class, false);
  }

  public Collection<ChildElementAssumption> getChildElementAssumptions() {
    return Arrays.asList(
          new ChildElementAssumption(Children.class, 0, 1)
        );
  }

  public Collection<AttributeAssumption> getAttributesAssumptions() {
    return Arrays.asList(
          new AttributeAssumption("name"),
          new AttributeAssumption("multiplicity", false, false, MultiplicityEnum.Unspecified),
          new AttributeAssumption("definitionRef"),
          new AttributeAssumption(CmmnModelConstants.CMMN10_NS, "sourceRef"),
          new AttributeAssumption("sourceRefs"),
          new AttributeAssumption("targetRefs")
        );
  }

}
